@@ -2,8 +2,8 @@
 Bringing Leaflet maps to PyQt.
 """
 
-__author__ = 'Samarth Hattangady <samarth@skylarkdrones.com>'
-__version__ = '0.3.3'
+__author__ = 'Leon Friedmann <leon.friedmann@tum.de>'
+__version__ = '0.4.5'
 
 from .mapwidget import MapWidget
 from .leaflet import L
